summaryrefslogtreecommitdiff
path: root/src/resources/buddylist.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/resources/buddylist.h')
-rw-r--r--src/resources/buddylist.h21
1 files changed, 5 insertions, 16 deletions
diff --git a/src/resources/buddylist.h b/src/resources/buddylist.h
index 32cce06a..5f082ba7 100644
--- a/src/resources/buddylist.h
+++ b/src/resources/buddylist.h
@@ -27,9 +27,6 @@
#include <guichan.hpp>
#include <list>
#include <string>
-#include <libxml/encoding.h>
-#include <libxml/xmlwriter.h>
-#include <libxml/xmlreader.h>
class BuddyList : public gcn::ListModel {
public:
@@ -64,27 +61,19 @@ class BuddyList : public gcn::ListModel {
std::string getElementAt(int number);
private:
- /**
- * Create a new XmlWriter for memory
- */
- void buddyXmlwriterMemory(void);
-
/**
- * Process node and load buddy
+ * Save buddy to file
*/
- void processNode(void);
+ void saveFile(void);
/**
* Parse a buddy XML file
*/
- void streamFile(void);
+ void loadFile(void);
std::list<std::string> buddylist; /**< Buddy list */
std::list<std::string>::iterator buddyit; /**< Iterator */
- xmlTextWriterPtr writer;
- xmlTextReaderPtr reader;
- xmlBufferPtr buf;
- std::string *filename; /* File to work with */
+ std::string *filename; /* File to work with */
};
#endif /* _TMW_BUDDYLIST_H */
@@ -64,27 +61,19 @@ class BuddyList : public gcn::ListModel {
/**
- * Parse a buddy XML file
+ * Load buddy from file
*/